Dialects — SQLAlchemy 1.3 Documentation

Release: 1.3.2 | Release Date: April 2, 2019

# SQLAlchemy 1.3 Documentation

# Dialects

The dialect is the system SQLAlchemy uses to communicate with various types of DBAPI implementations and databases. The sections that follow contain reference documentation and notes specific to the usage of each backend, as well as notes for the various DBAPIs.

All dialects require that an appropriate DBAPI driver is installed.

## Included Dialects

- PostgreSQL
- MySQL
- SQLite
- Oracle
- Microsoft SQL Server
- Firebird
- Sybase

## External Dialects

Currently maintained external dialect projects for SQLAlchemy include:

- ibm_db_sa - driver for IBM DB2 and Informix.

- PyHive - driver for Apache Hive and Presto.

- sqlalchemy-redshift - driver for Amazon Redshift, adapts the existing PostgreSQL/psycopg2 driver.

- sqlalchemy-drill - driver for Apache Drill.

- sqlalchemy-hana - driver for SAP Hana.

- sqlalchemy_exasol - driver for EXASolution.

- sqlalchemy-sqlany - driver for SAP Sybase SQL Anywhere, developed by SAP.

- sqlalchemy-monetdb - driver for MonetDB.

- snowflake-sqlalchemy - driver for Snowflake.

- sqlalchemy-tds - driver for MS-SQL, on top of python-tds.

- crate - driver for CrateDB.